==> socketstream-0.3.0.tar.gz: socketstream-0.3.0/src/inst.cc <==
// -*- Socket Streams -*-

// Copyright (C) 2003 Pedro Lamarao <pedro.lamarao@izcom.com.br>

// This file is part of the Socket Streams Library.  This library is free
// software; you can redistribute it and/or modify it under the
// terms of the GNU Lesser General Public License as published by the
// Free Software Foundation; either version 2.1 of the License
// or (at your option) any later version.

// This library is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU Lesser General Public License for more details.

// You should have received a copy of the GNU Lesser General Public License along
// with this library; see the file COPYING. If not, write to the Free
// Software Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307,
// USA

/** @file inst.cc
 * Template instantiations file.
 */

#include <socketstream/basic_socketbuf.h>
#include <socketstream/basic_isocketstream.h>
#include <socketstream/basic_osocketstream.h>
#include <socketstream/basic_iosocketstream.h>
#include <socketstream/basic_socketstream_listener.h>
#include <socketstream/basic_socketstream_pair.h>

namespace socketstream {
  template class basic_socketbuf<char, std::char_traits<char> >;
  template class basic_isocketstream<char, std::char_traits<char> >;
  template class basic_osocketstream<char, std::char_traits<char> >;
  template class basic_iosocketstream<char, std::char_traits<char> >;
  template class basic_listener<char, std::char_traits<char> >;
  template class basic_pair<char, std::char_traits<char> >;
}

==> socketstream-0.7.0.tar.gz: socketstream-0.7.0/src/inst.cc <==
// -*- Socket Streams -*-

// Copyright (C) 2003, 2004, 2005 Pedro Lamarão <pedro.lamarao@mndfck.org>

// This file is part of the Socket Streams Library.  This library is free
// software; you can redistribute it and/or modify it under the
// terms of the GNU Lesser General Public License as published by the
// Free Software Foundation; either version 2.1 of the License
// or (at your option) any later version.

// This library is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU Lesser General Public License for more details.

// You should have received a copy of the GNU Lesser General Public License along
// with this library; see the file COPYING. If not, write to the Free
// Software Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307,
// USA

/** @file inst.cc
 * Template instantiations file.
 */

#include <socketstream/basic_socketbuf.h>
#include <socketstream/basic_isocketstream.h>
#include <socketstream/basic_osocketstream.h>
#include <socketstream/basic_iosocketstream.h>
#include <socketstream/basic_socketstream_listener.h>
#if 0
#include <socketstream/basic_socketstream_pair.h>
#endif

namespace ss {
  template class basic_socketbuf<char, std::char_traits<char> >;
  template class basic_isocketstream<char, std::char_traits<char> >;
  template class basic_osocketstream<char, std::char_traits<char> >;
  template class basic_socketstream<char, std::char_traits<char> >;
  template class basic_listener<char, std::char_traits<char> >;
#if 0
  template class basic_pair<char, std::char_traits<char> >;
#endif
}
